==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/wafv2_rule_group/Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.java <==
package com.hashicorp.cdktf.providers.aws.wafv2_rule_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:56.149Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.wafv2RuleGroup.Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig")
@software.amazon.jsii.Jsii.Proxy(Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafv2_rule_group#fallback_behavior Wafv2RuleGroup#fallback_behavior}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFallbackBehavior();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafv2_rule_group#header_name Wafv2RuleGroup#header_name}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getHeaderName();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafv2_rule_group#position Wafv2RuleGroup#position}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPosition();

    /**
     * @return a {@link Builder} of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig> {
        java.lang.String fallbackBehavior;
        java.lang.String headerName;
        java.lang.String position;

        /**
         * Sets the value of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig#getFallbackBehavior}
         * @param fallbackBehavior Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafv2_rule_group#fallback_behavior Wafv2RuleGroup#fallback_behavior}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder fallbackBehavior(java.lang.String fallbackBehavior) {
            this.fallbackBehavior = fallbackBehavior;
            return this;
        }

        /**
         * Sets the value of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig#getHeaderName}
         * @param headerName Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafv2_rule_group#header_name Wafv2RuleGroup#header_name}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder headerName(java.lang.String headerName) {
            this.headerName = headerName;
            return this;
        }

        /**
         * Sets the value of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig#getPosition}
         * @param position Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafv2_rule_group#position Wafv2RuleGroup#position}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder position(java.lang.String position) {
            this.position = position;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig {
        private final java.lang.String fallbackBehavior;
        private final java.lang.String headerName;
        private final java.lang.String position;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.fallbackBehavior = software.amazon.jsii.Kernel.get(this, "fallbackBehavior", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.headerName = software.amazon.jsii.Kernel.get(this, "headerName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.position = software.amazon.jsii.Kernel.get(this, "position", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.fallbackBehavior = java.util.Objects.requireNonNull(builder.fallbackBehavior, "fallbackBehavior is required");
            this.headerName = java.util.Objects.requireNonNull(builder.headerName, "headerName is required");
            this.position = java.util.Objects.requireNonNull(builder.position, "position is required");
        }

        @Override
        public final java.lang.String getFallbackBehavior() {
            return this.fallbackBehavior;
        }

        @Override
        public final java.lang.String getHeaderName() {
            return this.headerName;
        }

        @Override
        public final java.lang.String getPosition() {
            return this.position;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("fallbackBehavior", om.valueToTree(this.getFallbackBehavior()));
            data.set("headerName", om.valueToTree(this.getHeaderName()));
            data.set("position", om.valueToTree(this.getPosition()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.wafv2RuleGroup.Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.Jsii$Proxy that = (Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.Jsii$Proxy) o;

            if (!fallbackBehavior.equals(that.fallbackBehavior)) return false;
            if (!headerName.equals(that.headerName)) return false;
            return this.position.equals(that.position);
        }

        @Override
        public final int hashCode() {
            int result = this.fallbackBehavior.hashCode();
            result = 31 * result + (this.headerName.hashCode());
            result = 31 * result + (this.position.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/wafv2_rule_group/Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.java <==
package com.hashicorp.cdktf.providers.aws.wafv2_rule_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.260Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.wafv2RuleGroup.Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig")
@software.amazon.jsii.Jsii.Proxy(Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_rule_group#fallback_behavior Wafv2RuleGroup#fallback_behavior}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFallbackBehavior();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_rule_group#header_name Wafv2RuleGroup#header_name}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getHeaderName();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_rule_group#position Wafv2RuleGroup#position}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPosition();

    /**
     * @return a {@link Builder} of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig> {
        java.lang.String fallbackBehavior;
        java.lang.String headerName;
        java.lang.String position;

        /**
         * Sets the value of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig#getFallbackBehavior}
         * @param fallbackBehavior Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_rule_group#fallback_behavior Wafv2RuleGroup#fallback_behavior}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder fallbackBehavior(java.lang.String fallbackBehavior) {
            this.fallbackBehavior = fallbackBehavior;
            return this;
        }

        /**
         * Sets the value of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig#getHeaderName}
         * @param headerName Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_rule_group#header_name Wafv2RuleGroup#header_name}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder headerName(java.lang.String headerName) {
            this.headerName = headerName;
            return this;
        }

        /**
         * Sets the value of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig#getPosition}
         * @param position Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_rule_group#position Wafv2RuleGroup#position}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder position(java.lang.String position) {
            this.position = position;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig {
        private final java.lang.String fallbackBehavior;
        private final java.lang.String headerName;
        private final java.lang.String position;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.fallbackBehavior = software.amazon.jsii.Kernel.get(this, "fallbackBehavior", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.headerName = software.amazon.jsii.Kernel.get(this, "headerName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.position = software.amazon.jsii.Kernel.get(this, "position", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.fallbackBehavior = java.util.Objects.requireNonNull(builder.fallbackBehavior, "fallbackBehavior is required");
            this.headerName = java.util.Objects.requireNonNull(builder.headerName, "headerName is required");
            this.position = java.util.Objects.requireNonNull(builder.position, "position is required");
        }

        @Override
        public final java.lang.String getFallbackBehavior() {
            return this.fallbackBehavior;
        }

        @Override
        public final java.lang.String getHeaderName() {
            return this.headerName;
        }

        @Override
        public final java.lang.String getPosition() {
            return this.position;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("fallbackBehavior", om.valueToTree(this.getFallbackBehavior()));
            data.set("headerName", om.valueToTree(this.getHeaderName()));
            data.set("position", om.valueToTree(this.getPosition()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.wafv2RuleGroup.Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.Jsii$Proxy that = (Wafv2RuleGroupRuleStatementIpSetReferenceStatementIpSetForwardedIpConfig.Jsii$Proxy) o;

            if (!fallbackBehavior.equals(that.fallbackBehavior)) return false;
            if (!headerName.equals(that.headerName)) return false;
            return this.position.equals(that.position);
        }

        @Override
        public final int hashCode() {
            int result = this.fallbackBehavior.hashCode();
            result = 31 * result + (this.headerName.hashCode());
            result = 31 * result + (this.position.hashCode());
            return result;
        }
    }
}
